module.exports = defineTest({
	description: 'does not consider nested tree-shaken variables when deconflicting'
});
